Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(136)

Unified Diff: net/base/net_log_util.h

Issue 848006: Generalize the net module's LoadLog facility from a passive container, to an event stream (NetLog). (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Split up RequestTracker into ConnectJobTracker+RequestTracker+RequestTrackerBase, address comments Created 10 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/base/net_log_unittest.h ('k') | net/base/net_log_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/base/net_log_util.h
===================================================================
--- net/base/net_log_util.h (revision 40318)
+++ net/base/net_log_util.h (working copy)
@@ -2,24 +2,24 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef NET_BASE_LOAD_LOG_UTIL_H_
-#define NET_BASE_LOAD_LOG_UTIL_H_
+#ifndef NET_BASE_NET_LOG_UTIL_H_
+#define NET_BASE_NET_LOG_UTIL_H_
#include <string>
#include <vector>
#include "base/basictypes.h"
-#include "net/base/load_log.h"
+#include "net/base/net_log.h"
namespace net {
-// The LoadLogUtil utility class contains methods to analyze and visualize
-// LoadLogs.
+// The NetLogUtil utility class contains methods to analyze and visualize
+// NetLog entries.
-class LoadLogUtil {
+class NetLogUtil {
public:
struct EventDuration {
- LoadLog::EventType event;
+ NetLog::EventType event;
base::TimeDelta duration;
};
typedef std::vector<EventDuration> EventDurationList;
@@ -63,12 +63,13 @@
// - Log entries added by AddEvent() have no prefix.
// - Time units are given as milliseconds.
//
- static std::string PrettyPrintAsEventTree(const LoadLog* log);
+ static std::string PrettyPrintAsEventTree(
+ const std::vector<NetLog::Entry>& entries, size_t num_entries_truncated);
private:
- DISALLOW_IMPLICIT_CONSTRUCTORS(LoadLogUtil);
+ DISALLOW_IMPLICIT_CONSTRUCTORS(NetLogUtil);
};
} // namespace net
-#endif // NET_BASE_LOAD_LOG_UTIL_H_
+#endif // NET_BASE_NET_LOG_UTIL_H_
« no previous file with comments | « net/base/net_log_unittest.h ('k') | net/base/net_log_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698